@@ -1,25 +1,11 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "notification.h"
-#include "notification_debug.h"
+#include "plugin_notification_debug.h"
 
 #include <KNotification>
 #include <QtGlobal>
@@ -105,13 +91,11 @@ void Notification::createKNotification(const NetworkPacket& np)
     QString escapedText = m_text.toHtmlEscaped();
     QString escapedTicker = m_ticker.toHtmlEscaped();
 
-#if KNOTIFICATIONS_VERSION >= QT_VERSION_CHECK(5, 57, 0)
     if (NotificationServerInfo::instance().supportedHints().testFlag(NotificationServerInfo::X_KDE_DISPLAY_APPNAME)) {
         m_notification->setTitle(escapedTitle);
         m_notification->setText(escapedText);
         m_notification->setHint(QStringLiteral("x-kde-display-appname"), m_appName.toHtmlEscaped());
     } else {
-#endif
         m_notification->setTitle(m_appName.toHtmlEscaped());
 
         if (m_title.isEmpty() && m_text.isEmpty()) {
@@ -125,22 +109,9 @@ void Notification::createKNotification(const NetworkPacket& np)
         } else {
             m_notification->setText(escapedTitle + QStringLiteral(": ") + escapedText);
         }
-
-#if KNOTIFICATIONS_VERSION >= QT_VERSION_CHECK(5, 57, 0)
     }
 
     m_notification->setHint(QStringLiteral("x-kde-origin-name"), m_device->name());
-#endif
-
-    m_hasIcon = m_hasIcon && !m_payloadHash.isEmpty();
-
-    if (!m_hasIcon) {
-        applyNoIcon();
-        show();
-    } else {
-        m_iconPath = m_imagesDir.absoluteFilePath(m_payloadHash);
-        loadIcon(np);
-    }
 
     if (!m_requestReplyId.isEmpty()) {
         m_actions.prepend(i18n("Reply"));
@@ -148,6 +119,15 @@ void Notification::createKNotification(const NetworkPacket& np)
     }
 
     m_notification->setActions(m_actions);
+
+    m_hasIcon = m_hasIcon && !m_payloadHash.isEmpty();
+
+    if (!m_hasIcon) {
+        show();
+    } else {
+        m_iconPath = m_imagesDir.absoluteFilePath(m_payloadHash);
+        loadIcon(np);
+    }
 }
 
 void Notification::loadIcon(const NetworkPacket& np)
@@ -169,7 +149,6 @@ void Notification::loadIcon(const NetworkPacket& np)
             s_downloadsInProgress.remove(m_iconPath);
             if (fileTransferJob->error()) {
                 qCDebug(KDECONNECT_PLUGIN_NOTIFICATION) << "Error in FileTransferJob: " << fileTransferJob->errorString();
-                applyNoIcon();
             } else {
                 applyIcon();
             }
@@ -184,12 +163,6 @@ void Notification::applyIcon()
     m_notification->setPixmap(icon);
 }
 
-void Notification::applyNoIcon()
-{
-    //HACK The only way to display no icon at all is trying to load a non-existent icon
-    m_notification->setIconName(QStringLiteral("not_a_real_icon"));
-}
-
 void Notification::reply()
 {
     Q_EMIT replyRequested();
